def get_article_url():
    """returns the article describing how to publish this package"""
    return "https://codesolid.com/python-package-example-setuptools"

def greet():
    """Say hi to setuptools so as not to appear rude"""
    return "Hello, setuptools!"